==> arla_0.23.orig.tar.gz: arla-0.23/xfs/solaris/xfs_wrap.c <==
/*
 * Copyright (c) 1995, 1996, 1997, 1998 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Kungliga Tekniska
 *      Hgskolan and its contributors.
 * 
 * 4. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 *
 * Load eXternal FS using modload under Solaris
 *
 * This is a filsystem, a pseudo device driver and a
 * systemcall.
 *
 */

#include <xfs/xfs_locl.h>
#include <xfs/xfs_message.h>
#include <xfs/xfs_dev.h>
#include <xfs/xfs_syscalls.h>

RCSID("$Id: xfs_wrap.c,v 1.4 1998/12/22 13:16:53 lha Exp $");

extern struct modlsys xfs_modlsys;

extern struct modldrv xfs_modldrv;

extern struct modlfs xfs_modlfs;

static struct modlinkage xfs_modlinkage = {
    MODREV_1,
    {(void *)&xfs_modlsys,
     (void *)&xfs_modldrv,
     (void *)&xfs_modlfs,
     NULL}
};

int
_init(void)
{
    int ret;

    ret = xfs_dev_init();
    if (ret)
	return ret;

    ret = mod_install(&xfs_modlinkage);
    if (ret) {
	xfs_dev_fini();
    }
    return ret;
}

int
_fini(void)
{
    int ret;

    ret = mod_remove(&xfs_modlinkage);
    if (ret)
	return ret;
    xfs_dev_fini();
    return ret;
}

int
_info(struct modinfo *modinfop)
{
    return mod_info(&xfs_modlinkage, modinfop);
}

==> arla-0.27.tar.gz: arla-0.27/xfs/solaris/xfs_wrap.c <==
/*
 * Copyright (c) 1995, 1996, 1997, 1998, 1999 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Kungliga Tekniska
 *      Hgskolan and its contributors.
 * 
 * 4. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 *
 * Load eXternal FS using modload under Solaris
 *
 * This is a filsystem, a pseudo device driver and a
 * systemcall.
 *
 */

#include <xfs/xfs_locl.h>
#include <xfs/xfs_message.h>
#include <xfs/xfs_dev.h>
#include <xfs/xfs_syscalls.h>

RCSID("$Id: xfs_wrap.c,v 1.6 1999/08/02 11:44:26 assar Exp $");

extern struct modlsys xfs_modlsys;

#ifdef _SYSCALL32_IMPL
extern struct modlsys xfs_modlsys32;
#endif

extern struct modldrv xfs_modldrv;

extern struct modlfs xfs_modlfs;

static struct modlinkage xfs_modlinkage = {
    MODREV_1,
    {(void *)&xfs_modlsys,
#ifdef _SYSCALL32_IMPL
     (void *)&xfs_modlsys32,
#endif
     (void *)&xfs_modldrv,
     (void *)&xfs_modlfs,
     NULL}
};

int
_init(void)
{
    int ret;

    ret = xfs_dev_init();
    if (ret)
	return ret;

    ret = mod_install(&xfs_modlinkage);
    if (ret) {
	xfs_dev_fini();
    }
    xfs_install_setgroups ();
    return ret;
}

int
_fini(void)
{
    int ret;

    ret = mod_remove(&xfs_modlinkage);
    if (ret)
	return ret;
    xfs_dev_fini();
    xfs_uninstall_setgroups ();
    return ret;
}

int
_info(struct modinfo *modinfop)
{
    return mod_info(&xfs_modlinkage, modinfop);
}
